import Vue from "vue"
import VueRouter from "vue-router"
import { userStore } from '@/store/userInfo'

Vue.use(VueRouter)

// 重写push||replace方法
// 先将原始push方法复制
let originPush=VueRouter.prototype.push
let originReplace=VueRouter.prototype.replace
// 重写
VueRouter.prototype.push=function(location,res,rej){
  // 如果传了成功,失败的回调
  if(res&&rej){
      originPush.call(this,location,res,rej)
  }else{
      originPush.call(this,location,()=>{},()=>{})
  }
}
VueRouter.prototype.replace=function(location,res,rej){
  if (res && rej) {
      originReplace.call(this, location, res, rej)
  } else {
      originReplace.call(this, location, () => { }, () => { })
  }
}

const router = new VueRouter({
  mode: "history",
  base: import.meta.env.BASE_URL,
  routes: [
    {
      path: "/",
      redirect: '/dashboard'
    },
    {
      path: "/login",
      name: "login",
      component: () => import("../views/Login.vue"),
    },
    {
      path: '',
      name: 'container',
      component: () => import("../views/Container.vue"),
      children: [
        {
          path: "/dashboard",
          name: "dashboard",
          component: () => import("../views/Dashboard.vue"),
        },
        {
          path: "/manage-team",
          name: "ManageTeam",
          component: () => import("../views/TeamManagement/ManageTeam.vue"),
        },
        {
          path: "/manage-member",
          name: "ManageMember",
          component: () => import("../views/TeamManagement/ManageMember.vue"),
        },
        {
          path: "/manage-member/edit-manage-member",
          name: "EditManageMember",
          component: () => import("../views/TeamManagement/ManageMember/EditManageMember.vue"),
        },
        {
          path: "/manage-member/add-manage-member",
          name: "AddManageMember",
          component: () => import("../views/TeamManagement/ManageMember/AddManageMember.vue"),
        },
        {
          path: "/manage-team/create-manage-team",
          name: "CreateManageTeam",
          component: () => import("../views/TeamManagement/ManageTeamOperate.vue"),
        },
        {
          path: "/manage-team/edit-manage-team",
          name: "EditManageTeam",
          component: () => import("../views/TeamManagement/ManageTeamOperate.vue"),
        },
        {
          path: "/settings",
          name: "settings",
          component: () => import("../views/Settings.vue"),
        },
        {
          path: "/device",
          name: "device",
          component: () => import("../views/Device.vue"),
        },
        {
          path: "/licenseManage",
          name: "licenseManage",
          component: () => import("../views/LicenseManage.vue"),
        },
        {
          path: "/assignlicense",
          name: "assignlicense",
          component: () => import("../views/Assignlicense.vue"),
        },
        {
          path: "/volumecancel",
          name: "volumecancel",
          component: () => import("../views/VolumeCancel.vue"),
        },
        {
          path: "/productManagement",
          name: "productManagement",
          component: () => import("../views/ProductManagement.vue"),
        },
        {
          path: "/manageAdmin",
          name: "manageAdmin",
          component: () => import("../views/ManageAdmin.vue"),
        },
        {
          path: "/manageAdmin/addAdmin",
          name: "addAdmin",
          component: () => import("../views/MenageAdmin/addAdmin.vue"),
        },
        {
          path: "/manageAdmin/editAdmin",
          name: "editAdmin",
          component: () => import("../views/MenageAdmin/editAdmin.vue"),
        },
        {
          path: "/support",
          name: "support",
          component: () => import("../views/Support.vue"),
        },
      ]
    },
    {
      path: "/noadmin",
      name: "noadmin",
      component: () => import("../views/Noadmin.vue"),
    },
    {
      path: "/Create",
      name: "Create",
      component: () => import("../views/Create.vue"),
    },
    {
      path: "/forgotpassword",
      name: "forgotpassword",
      component: () => import("../views/forgotpassword.vue"),
    },
    { // 当没有匹配到正确路由的时候，匹配404组件
      path: '*',
      name: "404",
      component: () => import("../views/notFind.vue"),
    }
  ],
})
router.beforeEach((to, from, next) => {
  const whiteList = '/login'
  //路由守卫，进行权限判断
  if (to.path !== whiteList && to.path !== '/Create' && to.path !== '/noadmin' && to.path !== '/forgotpassword') {
    if (userStore().user.role?.indexOf("2") !== -1 || userStore().user.role?.indexOf("1") !== -1) {
      next()
    } else {
      next('/noadmin')
    }
  } else {
    next()
  }
})


export default router
